remm 2003/05/23 03:54:15
Modified: catalina/src/share/org/apache/catalina Container.java
Log:
- Better name: backgroundProcess.
Revision Changes Path
1.5 +10 -10 jakarta-tomcat-catalina/catalina/src/share/org/apache/catalina/Container.java
Index: Container.java
===================================================================
RCS file: /home/cvs/jakarta-tomcat-catalina/catalina/src/share/org/apache/catalina/Container.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- Container.java 22 May 2003 23:03:13 -0000 1.4
+++ Container.java 23 May 2003 10:54:15 -0000 1.5
@@ -253,7 +253,7 @@
/**
* Get the delay between the invocation of the execute method on
* this container and its children. Child containers will not be invoked
* if their delay value is not negative (which would mean they are using
* their own thread). Setting this to a positive value will cause
@@ -261,17 +261,17 @@
* the thread will invoke the executePeriodic method on this container
* and all its children.
*/
- public int getExecuteDelay();
+ public int getBackgroundProcessorDelay();
/**
* Set the delay between the invocation of the execute method on this
* container and its children.
*
* @param delay The delay in seconds between the invocation of execute
* methods
*/
- public void setExecuteDelay(int delay);
+ public void setBackgroundProcessorDelay(int delay);
/**
@@ -374,7 +374,7 @@
* invoked inside the classloading context of this container. Unexpected
* throwables will be caught and logged.
*/
- public void execute();
+ public void backgroundProcess();
/**
---------------------------------------------------------------------
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org
|
@@ -253,7 +253,7 @@
/**
- * Get the delay between the invocation of the execute method on
+ * Get the delay between the invocation of the backgroundProcess method on
* this container and its children. Child containers will not be invoked
* if their delay value is not negative (which would mean they are using
@@ -261,17 +261,17 @@
* container and its children.
*
- * @param delay The delay in seconds between the invocation of execute
- * methods
+ * @param delay The delay in seconds between the invocation of
+ * backgroundProcess methods
*/